---
title: '[공지] PG가입비 무료 프로모션 종료 안내 '
category: 공지사항
tags:
  - 공지사항
  - 가입비
pgCompanies:
  - 공통
searchTags:
  - Pg가입비
  - 유료
  - 무료
  - 이용요금
  - 가입비
datetime: 2024-06-10T15:00:00.000Z
---

안녕하세요. PortOne 팀 입니다. 😊

오랜 기간 진행 되었던 **PG가입비 무료 프로모션 종료**에 대한 공지 입니다.

현재까지 포트원과 제휴된 모든 PG사 대상으로 가입비 무료 프로모션을 제공하였으나, PG사 가입비 정책 변경으로 아래와 같이 무료 혜택 적용이 종료 될 예정입니다.  서비스 이용에 불편함 없으시도록 참고 부탁드립니다.

- 가입비 무료 프로모션 종료 일자 : 2024년 06월 30일 (해당 일자 신청 건 까지 프로모션 적용)

앞으로도 더 좋은 경험과 서비스를 제공해 드리기 위해 노력하겠습니다.

감사합니다.

<Callout content="PG가입비는 포트원 연동 PG사별 사업자당 1회 납부 진행되며, 기존 포트원을 통해 연동한 PG에 대해 MID를 추가하는 경우에는 가입비 납부를 진행하지 않으셔도 됩니다" icon="💡" title="참고사항" />
